@@ -150,6 +150,7 @@ COSE_ALGORITHMS_SIG_RSA = {
     # etc.
 }
 
+# JOSE Algorithms supported.
 JOSE_ALGORITHMS_SUPPORTED = {
     "RS512": -259,
     "RS384": -258,
@@ -205,3 +206,9 @@ COSE_ALGORITHMS_SYMMETRIC = dict(COSE_ALGORITHMS_MAC, **COSE_ALGORITHMS_CEK)
 
 # COSE Algorithms for RSA Keys.
 COSE_ALGORITHMS_RSA = dict(COSE_ALGORITHMS_SIG_RSA)
+
+# All of Supported COSE Algorithms.
+COSE_ALGORITHMS = dict(COSE_ALGORITHMS_RSA, **COSE_ALGORITHMS_SYMMETRIC)
+
+# COSE Named Algorithms for converting from JWK-like key.
+COSE_NAMED_ALGORITHMS_SUPPORTED = dict(JOSE_ALGORITHMS_SUPPORTED, **COSE_ALGORITHMS)
